@@ -1,6 +1,6 @@
 package wApua::About;
 
-# Copyright (C) 2000, 2006, 2009, 2016 by Axel Beckert <wapua@deuxchevaux.org>
+# Copyright (C) 2000, 2006, 2009, 2016, 2022 by Axel Beckert <wapua@deuxchevaux.org>
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -184,8 +184,8 @@ pages on the web...
 
 </p><small><p>
 
-<b>Copyright &#xA9; 2000, 2006, 2009 by
-<a href='http://fsinfo.noone.org/~abe/index.wml'>Axel Beckert</a>
+<b>Copyright &#xA9; 2000, 2006, 2009, 2016, 2017, 2022 by
+<a href='https://fsinfo.noone.org/~abe/index.wml'>Axel Beckert</a>
 <a href='mailto:wapua\@deuxchevaux.org'>&lt;wapua\@deuxchevaux.org&gt;</a></b>
 
 </p><p>
@@ -222,20 +222,20 @@ You can reach the author by <a href='about:#author'>snail-mail and e-mail</a>.
 Axel Beckert<br/>
 <table columns='2'><tr>
 	<td>Mail:</td>
-	<td>Krbergstrasse 20<br/>
-	    8049 Zrich, Switzerland</td>
+	<td>K&#xFC;rbergstrasse 20<br/>
+	    8049 Z&#FC;rich, Switzerland</td>
 </tr><tr>
 	<td>E-Mail:</td>
 	<td><a href='mailto:wapua\@deuxchevaux.org'
 		>&lt;wapua\@deuxchevaux.org&gt;</a></td>
 </tr><tr>
 	<td>WWW:</td>
-	<td><a href='http://abe.home.pages.de/english.html'
-		>http://abe.home.pages.de/english.html</a></td>
+	<td><a href='https://axel.beckert.ch/'
+		>https://axel.beckert.ch/</a></td>
 </tr><tr>
 	<td>WAP:</td>
-	<td><a href='http://fsinfo.noone.org/~abe/index.wml'
-		>http://fsinfo.noone.org/~abe/index.wml</a></td>
+	<td><a href='https://fsinfo.noone.org/~abe/index.wml'
+		>https://fsinfo.noone.org/~abe/index.wml</a></td>
 </tr></table>
 
 </p></small></card><card id='download' title='wApua Download'><p>
@@ -248,12 +248,12 @@ You can download the actual version of wApua at the wApua Home Page.
 
 <table columns='2'><tr>
 	<td>WML version</td>
-	<td><a href='http://fsinfo.noone.org/~abe/wApua/index.wml'
-	    >http://fsinfo.noone.org/~abe/wApua/index.wml</a></td>
+	<td><a href='https://fsinfo.noone.org/~abe/wApua/index.wml'
+	    >https://fsinfo.noone.org/~abe/wApua/index.wml</a></td>
 </tr><tr>
 	<td>HTML version</td>
-	<td><a href='http://fsinfo.noone.org/~abe/wApua/index.html'
-	    >http://fsinfo.noone.org/~abe/wApua/index.html</a></td>
+	<td><a href='https://fsinfo.noone.org/~abe/wApua/index.html'
+	    >https://fsinfo.noone.org/~abe/wApua/index.html</a></td>
 </tr></table>
 
 </p></small></card><card id='info' title='Program environment'><p>
